@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: xmonad
-version: 0.9.2
-id: xmonad-0.9.2-cf18bf074930804b3d2397579ea50a3c
+version: 0.10
+id: xmonad-0.10-9098873644798ba05a3da4f132de9a0a
 
 license: BSD3
 copyright:
@@ -25,27 +25,28 @@ exposed: True
 exposed-modules: XMonad XMonad.Main XMonad.Core XMonad.Config
                  XMonad.Layout XMonad.ManageHook XMonad.Operations XMonad.StackSet
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/xmonad-0.9.2
-library-dirs: /usr/local/lib/ghc/xmonad-0.9.2
-hs-libraries: HSxmonad-0.9.2
+import-dirs: /usr/local/lib/ghc/xmonad-0.10
+library-dirs: /usr/local/lib/ghc/xmonad-0.10
+hs-libraries: HSxmonad-0.10
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: X11-1.5.0.0-36d317925f45deb13d15f41314b23680
-         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
-         directory-1.1.0.0-9315160d2d0511510edc9d31fb968f3c
+depends: X11-1.6.0-34d5fa7e6b479ed438484c2315a89d50
+         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
+         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
+         directory-1.1.0.0-0764d4838863123df574e64d163bd619
          extensible-exceptions-0.1.1.2-d8c5b906654260efd7249f497d17a831
-         filepath-1.2.0.0-b273467b63dd15270d77af61bc610112
-         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
-         process-1.0.1.5-55dfaccf3a91c4cb8f6284a0bafef198
-         unix-2.4.2.0-090cf1b1ab645511a5a62d8d94ee4eb7
+         filepath-1.2.0.0-b4f4cf7e95546b00f075372f0ccb0653
+         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
+         process-1.0.1.5-da4848a2eec47420cd09fe9edba7e83c
+         unix-2.4.2.0-ede8c1b2fd228f3f436412134498aafc
+         utf8-string-0.3.6-213e09c7f4f705610e4e35b79f03acb5
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-xmonad-0.9.2/html/xmonad.haddock
-haddock-html: /usr/local/share/doc/hs-xmonad-0.9.2/html
+haddock-interfaces: /usr/local/share/doc/hs-xmonad-0.10/html/xmonad.haddock
+haddock-html: /usr/local/share/doc/hs-xmonad-0.10/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
